@@ -37,6 +37,7 @@ gen.struct <-
     "ivs",      ## data for hat and squeeze
     "lpdf",     ## log-density
     "A.ht.tot", ## total area below hat
+    "A.sq.tot", ## total area below squeeze
     "env",      ## environment for evaluating log-density
     "iniv",     ## initial intervals (for print.Tinflex)
     "Acum",     ## cumulated areas
@@ -63,6 +64,7 @@ Tinflex.setup <- function(lpdf, dlpdf, d2lpdf, ib, cT=0, rho=1.1, max.intervals=
   ##                the last interval just stores the right boundary of domain
   ##   lpdf     ... log-density 
   ##   A.ht.tot ... total area below hat
+  ##   A.sq.tot ... total area below squeeze
   ##   env      ... environment for evaluating log-density in C
   ## -----------------------------------------------------------------------
 
@@ -74,7 +76,7 @@ Tinflex.setup <- function(lpdf, dlpdf, d2lpdf, ib, cT=0, rho=1.1, max.intervals=
 
   if (!isTRUE(max.intervals > 51)) {
     warning ("argument 'max.intervals' too small or invalid, using default")
-    rho <- 1001
+    max.intervals <- 1001
   }
 
   if (missing(lpdf) || !is.function(lpdf))
@@ -162,7 +164,7 @@ Tinflex.setup <- function(lpdf, dlpdf, d2lpdf, ib, cT=0, rho=1.1, max.intervals=
 
   ## We have to split intervals where the area
   ## between hat and squueze is too large.
-  while (! is.TRUE(A.ht.tot / A.sq.tot <= rho)) {
+  while (! is.TRUE(is.TRUE(A.ht.tot / A.sq.tot <= rho))) {
 
     ## Compute average area.
     threshold <- 0.99 * (A.ht.tot - A.sq.tot) / n.ivs
@@ -203,14 +205,28 @@ Tinflex.setup <- function(lpdf, dlpdf, d2lpdf, ib, cT=0, rho=1.1, max.intervals=
   }
 
   ## Check result.
-  if (! (is.finite(A.ht.tot) && is.finite(A.sq.tot)) )
-    stop ("Cannot create hat function for given distribution")
+  if (! is.finite(A.ht.tot)) {
+      stop ("Cannot create hat function. A_hat is not finite: A_hat=", A.ht.tot)
+  } 
+    
+  if (! is.TRUE(A.ht.tot > 0.)) {
+      stop ("Cannot create hat function. A_hat is not > 0: A_hat=", A.ht.tot)
+  } 
+
+  if (! is.finite(A.sq.tot)) {
+      stop ("Cannot create squeeze. A_squeeze is not finite: A_squeeze=", A.sq.tot)
+  } 
+    
+  if (! is.TRUE(A.sq.tot >= 0.)) {
+      stop ("Cannot create squeeze. A_squeeze is not >= 0: A_squeeze=", A.sq.tot)
+  } 
 
   if (is.TRUE(A.ht.tot < A.sq.tot))
-    stop ("Invalid input: A.hat < A.squeeze!")
+      stop ("Invalid input: A_hat < A_squeeze!")
   
-  if (A.ht.tot / A.sq.tot > rho)
-    warning ("parameter 'rho' larger than requested")
+  if (!is.TRUE(A.ht.tot / A.sq.tot <= rho))
+      warning ("ratio A_hat / A_squeeze = ", A.ht.tot / A.sq.tot,
+               " is larger than rho = ",rho)
 
   ## Truncate working array.
   params <- params[,1:(n.ivs+1)]
@@ -232,6 +248,7 @@ Tinflex.setup <- function(lpdf, dlpdf, d2lpdf, ib, cT=0, rho=1.1, max.intervals=
   generator <- list(ivs=params,          ## data for hat and squeeze
                     lpdf=lpdf,           ## log-density
                     A.ht.tot=A.ht.tot,   ## total area below hat
+                    A.sq.tot=A.sq.tot,   ## total area below hat
                     env=parent.frame(),  ## environment for evaluating log-density
                     iniv=iniv,           ## initial intervals (for print.Tinflex)
                     Acum=Acum,           ## cumulated areas
